==> com.liferay.portal.workflow.api-1.2.3-sources.jar: com/liferay/portal/workflow/constants/WorkflowWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.workflow.constants;

/**
 * @author Adam Brandizzi
 */
public class WorkflowWebKeys {

	public static final String SELECTED_WORKFLOW_PORTLET_TAB =
		"SELECTED_WORKFLOW_PORTLET_TAB";

	public static final String WORKFLOW_DEFINITION_DISPLAY_CONTEXT =
		"WORKFLOW_DEFINITION_DISPLAY_CONTEXT";

	public static final String WORKFLOW_DEFINITION_LINK_DISPLAY_CONTEXT =
		"WORKFLOW_DEFINITION_LINK_DISPLAY_CONTEXT";

	public static final String WORKFLOW_DEFINITION_MODIFIED_DATE =
		"WORKFLOW_DEFINITION_MODIFIED_DATE";

	public static final String WORKFLOW_DEFINITION_NAME =
		"WORKFLOW_DEFINITION_NAME";

	public static final String WORKFLOW_JSP_STATE = "jsp_state";

	public static final String WORKFLOW_NAVIGATION_DISPLAY_CONTEXT =
		"WORKFLOW_NAVIGATION_DISPLAY_CONTEXT";

	public static final String WORKFLOW_PORTLET_TABS = "WORKFLOW_PORTLET_TABS";

	public static final String WORKFLOW_PREVIEW_BEFORE_RESTORE_STATE =
		"previewBeforeRevert";

	public static final String WORKFLOW_PUBLISH_DEFINITION_ACTION =
		"WORKFLOW_PUBLISH_DEFINITION_ACTION";

	public static final String WORKFLOW_SELECTED_PORTLET_TAB =
		"WORKFLOW_PORTLET_TAB";

	public static final String WORKFLOW_TAB_DEFINITION = "workflows";

	public static final String WORKFLOW_TAB_DEFINITION_LINK = "schemes";

	public static final String WORKFLOW_TAB_INSTANCE = "monitoring";

	public static final String WORKFLOW_TAB_MY_SUBMISSIONS = "my-submissions";

}

==> com.liferay.portal.workflow.api-9.0.0-sources.jar: com/liferay/portal/workflow/constants/WorkflowWebKeys.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.portal.workflow.constants;

/**
 * @author Adam Brandizzi
 */
public class WorkflowWebKeys {

	public static final String SELECTED_WORKFLOW_PORTLET_TAB =
		"SELECTED_WORKFLOW_PORTLET_TAB";

	public static final String WORKFLOW_DEFINITION_DISPLAY_CONTEXT =
		"WORKFLOW_DEFINITION_DISPLAY_CONTEXT";

	public static final String WORKFLOW_DEFINITION_LINK_DISPLAY_CONTEXT =
		"WORKFLOW_DEFINITION_LINK_DISPLAY_CONTEXT";

	public static final String WORKFLOW_DEFINITION_MODIFIED_DATE =
		"WORKFLOW_DEFINITION_MODIFIED_DATE";

	public static final String WORKFLOW_DEFINITION_NAME =
		"WORKFLOW_DEFINITION_NAME";

	public static final String WORKFLOW_INSTANCE_EDIT_DISPLAY_CONTEXT =
		"WORKFLOW_INSTANCE_EDIT_DISPLAY_CONTEXT";

	public static final String WORKFLOW_INSTANCE_ID = "WORKFLOW_INSTANCE_ID";

	public static final String WORKFLOW_JSP_STATE = "jsp_state";

	public static final String WORKFLOW_NAVIGATION_DISPLAY_CONTEXT =
		"WORKFLOW_NAVIGATION_DISPLAY_CONTEXT";

	public static final String WORKFLOW_PORTLET_TABS = "WORKFLOW_PORTLET_TABS";

	public static final String WORKFLOW_PREVIEW_BEFORE_RESTORE_STATE =
		"previewBeforeRevert";

	public static final String WORKFLOW_PUBLISH_DEFINITION_ACTION =
		"WORKFLOW_PUBLISH_DEFINITION_ACTION";

	public static final String WORKFLOW_SELECTED_PORTLET_TAB =
		"WORKFLOW_PORTLET_TAB";

	public static final String WORKFLOW_TAB_DEFINITION = "workflows";

	public static final String WORKFLOW_TAB_DEFINITION_LINK = "configuration";

	public static final String WORKFLOW_TAB_INSTANCE = "submissions";

	public static final String WORKFLOW_TAB_MY_SUBMISSIONS = "my-submissions";

}
